import { Injectable } from '@angular/core';

import { WebSocketService } from './websocket.service';
import { ProcessCommand } from './processcommand';


@Injectable()
export class ProcessManagerService {
  key = 'processmanager';
  process_name: string;

  constructor(private webSocketService: WebSocketService) {}

  init(process_name: string) {
    this.process_name = process_name;
    this.webSocketService.connect();
  }

  subscribeCallback(callback: (event: any) => void) {
    this.webSocketService.observeKey<ProcessCommand>(this.key).subscribe(callback);
  }

  sendCommand(command: string, callback?: (event: any) => void) {
    if (callback) {
      this.subscribeCallback(callback);
    }
    this.webSocketService.send(this.key, {'command': command});
  }

  startProcess(callback?: (event: any) => void) {
    this.sendCommand('start', callback);
  }

  stopProcess(callback?: (event: any) => void) {
    this.sendCommand('stop', callback);
  }

  restartProcess(callback?: (event: any) => void) {
    this.sendCommand('restart', callback);
  }
}
